@@ -1,3 +1,5 @@
+import Acquisition
+
 class MaybeRedirectView(object):
 
     def __call__(self, **kwargs):
@@ -30,4 +32,6 @@ class MaybeRedirectView(object):
                     results[0].getRemoteUrl, status=301, lock=1)
 
         plone_templates = self.context.portal_skins.plone_templates
-        return plone_templates.standard_error_message(**kwargs)
+        return Acquisition.aq_base(
+            plone_templates.standard_error_message).__of__(
+            Acquisition.aq_inner(self.context))(**kwargs)
